
dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
dialogStr("Hier is weer iets naar beneden komen zetten.")


dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
dialogStr("Het is een soort schelpdier. We zullen het wel weer de trap op moeten duwen.")


dialogId("sch-v-setkani", "font_big", "I can see it now: ‘Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
dialogStr("Dat wordt dan \"Schelpdier Ontmoet Bloempot\". Dat is bijna net zo erg als een strijkijzer en een naaimachine die elkaar op een operatietafel ontmoeten.")


dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
dialogStr("Sorry, ik was een beetje te enthousiast.")


dialogId("sch-m-moc1", "font_small", "Sorry, I was momentarily distracted.")
dialogStr("Sorry, ik zat even niet op te letten.")


dialogId("sch-m-moc2", "font_small", "Where I am going with this shell?")
dialogStr("Waar moet deze schelp heen?")

